<?php

namespace Restaurant\Restaurant\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Restaurant\Restaurant\Interfaces\MenuRepositoryInterface;

class MenuPublicController extends BaseController
{
    // use MenuWorkflow;

    /**
     * Constructor.
     *
     * @param type \Restaurant\Menu\Interfaces\MenuRepositoryInterface $menu
     *
     * @return type
     */
    public function __construct(MenuRepositoryInterface $menu)
    {
        $this->repository = $menu;
        parent::__construct();
    }

    /**
     * Show menu's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $menus = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$restaurant::menu.names'))
            ->view('restaurant::menu.index')
            ->data(compact('menus'))
            ->output();
    }


    /**
     * Show menu.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $menu = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$menu->name . trans('restaurant::menu.name'))
            ->view('restaurant::menu.show')
            ->data(compact('menu'))
            ->output();
    }

}
